*****************************************************************************************
/* 	Recode
	Conjoint Spanish survey
	September 2014
*/
*****************************************************************************************

cd "~/Dropbox/papers in progress/conjoint/data/"
use "spain_survey.dta", clear
save "co_data.dta", replace

*****************************************************************************************
***********************

drop EXP1 EXP1_ORDEN Q1-Q1A  EXP3-Q7  EXP6_Q10-Q11_6  EXPK-Q62E_4

****************Conjoint experiment

**Recode experimental variables
gen changes1 = EXP2_Q2_V1_AT1
gen changes2 = EXP2_Q2_V2_AT1 
gen changes3 = EXP2_Q3_V1_AT1 
gen changes4 = EXP2_Q3_V2_AT1

gen training1 = EXP2_Q2_V1_AT2 
gen training2 = EXP2_Q2_V2_AT2 
gen training3 = EXP2_Q3_V1_AT2 
gen training4 = EXP2_Q3_V2_AT2

gen recipient1 = EXP2_Q2_V1_AT3 
gen recipient2 = EXP2_Q2_V2_AT3 
gen recipient3 = EXP2_Q3_V1_AT3 
gen recipient4 = EXP2_Q3_V2_AT3 

gen cost1 = EXP2_Q2_V1_AT4 
gen cost2 = EXP2_Q2_V2_AT4 
gen cost3 = EXP2_Q3_V1_AT4 
gen cost4 = EXP2_Q3_V2_AT4 

gen source1 = EXP2_Q2_V1_AT5 
gen source2 = EXP2_Q2_V2_AT5 
gen source3 = EXP2_Q3_V1_AT5 
gen source4 = EXP2_Q3_V2_AT5

gen vote1 = .
recode vote1 (.=1) if Q2==1
recode vote1 (.=0) if Q2==2

gen vote2 = .
recode vote2 (.=1) if Q2==2
recode vote2 (.=0) if Q2==1

gen vote3 = .
recode vote3 (.=1) if Q3==1
recode vote3 (.=0) if Q3==2

gen vote4 = .
recode vote4 (.=1) if Q3==2
recode vote4 (.=0) if Q3==1

reshape long changes training recipient cost source vote, i(numericalId) j(candidate)

label define changes 1 "No change" 2 "Longer 426E subsidy" 3 "Increase at start" 4 "Constant benefits", modify
label values changes changes
label variable changes "Changes in benefits"

label define training 1 "No change" 2 "Public services" 3 "Companies" 4 "Trade unions", modify
label values training training
label variable training "Training to the unemployed"

label define recipient 1 "Everyone" 2 "Spanish citizens" 3 "Below median salary" 4 "No salary in HH", modify
label values recipient recipient
label variable recipient "Recipients"

label define cost 1 "100 million" 2 "1000 million" 3 "2000 million" 4 "3000 million", modify
label values cost cost
label variable cost "Cost in euros"

label define source 1 "Indirect taxes" 2 "Income tax" 3 "Public debt" 4 "Education and health" 5 "Police and defense", modify
label values source source
label variable source "Source of funding"

**Other variables

**Economic

gen emplsit =.
*Work permanent contract
recode emplsit .=1 if Q47A==1
*Work temporary contract
recode emplsit .=2 if Q47A==2
*Work black market
recode emplsit .=3 if Q47A==3
*Unemployed
recode emplsit .=4 if Q45==2
*Other
recode emplsit .=5 if Q45>2
label define emplsit 1 "Permanent contract" 2 "Temporary contract" ///
	3 "Black market" 4 "Unemployed" 5 "Other", modify
label values emplsit emplsit
label variable emplsit "Employment situation"

recode emplsit (3=.) (4=3) (5=.), gen(emplsit3c)
label define emplsit3c 1 "Permanent contract" 2 "Temporary contract" 3 "Unemployed", modify
label values emplsit3c emplsit3c 
label variable emplsit3c "Employment situation in 3 categories"

gen income = Q44
label variable income "Household income"

recode Q44 (1/2=1) (3/5=2) (6/10=3) (11=.), gen(inc3c)
label define inc3c 1 "Up to 1,160" 2 "1,161-1,750" 3 "More than 1,750", modify
label values inc3c inc3c 
label variable inc3c "Household income"

gen loosejob = Q49A
label variable loosejob "Likelihood of loosing job"

recode Q49A (1/2=1) (3=2) (4=3), gen(riskjob)
label define riskjob 1 "Likely" 2 "Not very likely" 3 "Not at all likely", modify
label values riskjob riskjob 
label variable riskjob "Perceived risk of losing job in 3 categories"

*Income 
recode Q44 (11=.)

*Ideology
factor Q64_1 Q64_2 Q64_3
predict ethno
label variable ethno "Ethnocentrism"

factor Q16 Q15 Q18B  Q13 
predict econissues
label variable econissues "Position on economic issues" 

egen econissues3c = cut(econissues), group(3)
label variable econissues3c "Economic issues" 

gen ideol= Q32
label variable ideol "Ideology 0-10"

recode Q32 (0/4=1) (5=2) (6/10=3), gen(ide3c)
label define ide3c 1 "Left (0/4)" 2 "Center (5)" 3 "Right (6-10)", modify
label values ide3c ide3c 
label variable ide3c "Ideology"


*Other variables
gen risk = Q36
label variable risk "Propensity to take risks 0-10"
recode risk (0/4=0) (5=1) (6/10=2), gen(risk3c)
label define risk3c 0 "Risk averse" 1 "Risk neutral" 2 "Risk prone", modify
label values risk3c risk3c 
label variable risk3c "Propensity to take risks in 3 categories"

gen altr=Q8_DONAR
recode altr (0/2=0) (3/4=1), gen(altr2c)
label define altr2c 0 "Low altruism" 1 "High altruism", modify
label values altr2c altr2c 
label variable altr2c "Altruism in 2 categories"

recode ethno (-3/0=1) (0/3=0), gen(ethn2c)
label define ethn2c 0 "Low ethnocentrism" 1 "High ethnocentrism", modify
label values ethn2c ethn2c 
label variable ethn2c "Ethnocentrism in 2 categories"


**Occupational risk (EPA 2nd quarter 2014)
gen occrisk=.
recode occrisk .=5.2 if Q51==1 & Q51_1==11
recode occrisk .=4.1 if Q51==1 & Q51_1==12
recode occrisk .=3.8 if Q51==1 & Q51_1==13
recode occrisk .=3.3 if Q51==1 & Q51_1==14
recode occrisk .=2.1 if Q51==1 & Q51_1==99
recode occrisk .=5.5 if Q51==2 & Q51_2==21
recode occrisk .=2.7 if Q51==2 & Q51_2==22
recode occrisk .=4 if Q51==2 & Q51_2==23
recode occrisk .=4.1 if Q51==2 & Q51_2==24
recode occrisk .=3.1 if Q51==2 & Q51_2==25
recode occrisk .=5 if Q51==2 & Q51_2==26
recode occrisk .=4 if Q51==2 & Q51_2==99
recode occrisk .=6 if Q51==3 & Q51_3==31
recode occrisk .=7.4 if Q51==3 & Q51_3==32
recode occrisk .=7 if Q51==3 & Q51_3==33
recode occrisk .=11.3 if Q51==3 & Q51_3==34
recode occrisk .=7.1 if Q51==3 & Q51_3==35
recode occrisk .=7.2 if Q51==3 & Q51_3==99
recode occrisk .=6.8 if Q51==4 & Q51_4==41
recode occrisk .=12.7 if Q51==4 & Q51_4==42
recode occrisk .=5.7 if Q51==4 & Q51_4==43
recode occrisk .=10 if Q51==4 & Q51_4==44
recode occrisk .=7.5 if Q51==4 & Q51_4==99
recode occrisk .=11 if Q51==5 & Q51_5==51
recode occrisk .=12.3 if Q51==5 & Q51_5==52
recode occrisk .=7.5 if Q51==5 & Q51_5==53
recode occrisk .=7.9 if Q51==5 & Q51_5==54
recode occrisk .=12.2 if Q51==5 & Q51_5==99
recode occrisk .=8 if Q51==6 & Q51_6==61
recode occrisk .=13.5 if Q51==6 & Q51_6==62
recode occrisk .=13.5 if Q51==6 & Q51_6==62
recode occrisk .=7.3 if Q51==6 & Q51_6==99
recode occrisk .=23.1 if Q51==7 & Q51_7==71
recode occrisk .=11 if Q51==7 & Q51_7==72
recode occrisk .=11 if Q51==7 & Q51_7==73
recode occrisk .=10.2 if Q51==7 & Q51_7==74
recode occrisk .=10 if Q51==7 & Q51_7==75
recode occrisk .=15.3 if Q51==7 & Q51_7==99
recode occrisk .=8.8 if Q51==8 & Q51_8==81
recode occrisk .=10.1 if Q51==8 & Q51_8==82
recode occrisk .=10 if Q51==8 & Q51_8==83
recode occrisk .=9.2 if Q51==8 & Q51_8==99
recode occrisk .=12 if Q51==9 & Q51_9==91
recode occrisk .=45.2 if Q51==9 & Q51_9==92
recode occrisk .=20.1 if Q51==9 & Q51_9==93
recode occrisk .=25.2 if Q51==9 & Q51_9==94
recode occrisk .=25.8 if Q51==9 & Q51_9==95
recode occrisk .=25.8 if Q51==9 & Q51_9==96
recode occrisk .=24.2 if Q51==9 & Q51_9==99
recode occrisk .=0.7 if Q51==10 & Q51_10==1
recode occrisk .=0.7 if Q51==10 & Q51_10==2
recode occrisk .=0.7 if Q51==10 & Q51_10==3
recode occrisk .=0.7 if Q51==10 & Q51_10==99
recode occrisk .=24.5 if Q51==99

egen occrisk3c = cut(occrisk), group(3)
label variable occrisk3c "Occupational risk" 
label define occrisk3c 0 "Low risk" 1 "Medium risk" 2 "High risk", modify
label values occrisk3c occrisk3c

gen ethnorev=ethno*(-1)

**Occupational risk is only estimated for the active (occupied+unemployed)
*Hence, there is a large number of missing cases (2012 out of 6032)

save "co_data.dta", replace
saveold "co_data_old.dta", replace


****************************************************************************

